VirtualFluids 0.2.0
Parallel CFD LBM Solver
Loading...
Searching...
No Matches
Slip.cu
Go to the documentation of this file.
1//=======================================================================================
2// ____ ____ __ ______ __________ __ __ __ __
3// \ \ | | | | | _ \ |___ ___| | | | | / \ | |
4// \ \ | | | | | |_) | | | | | | | / \ | |
5// \ \ | | | | | _ / | | | | | | / /\ \ | |
6// \ \ | | | | | | \ \ | | | \__/ | / ____ \ | |____
7// \ \ | | |__| |__| \__\ |__| \________/ /__/ \__\ |_______|
8// \ \ | | ________________________________________________________________
9// \ \ | | | ______________________________________________________________|
10// \ \| | | | __ __ __ __ ______ _______
11// \ | | |_____ | | | | | | | | | _ \ / _____)
12// \ | | _____| | | | | | | | | | | \ \ \_______
13// \ | | | | |_____ | \_/ | | | | |_/ / _____ |
14// \ _____| |__| |________| \_______/ |__| |______/ (_______/
15//
16// This file is part of VirtualFluids. VirtualFluids is free software: you can
17// redistribute it and/or modify it under the terms of the GNU General Public
18// License as published by the Free Software Foundation, either version 3 of
19// the License, or (at your option) any later version.
20//
21// VirtualFluids is distributed in the hope that it will be useful, but WITHOUT
22// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
23// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
24// for more details.
25//
26// SPDX-License-Identifier: GPL-3.0-or-later
27// SPDX-FileCopyrightText: Copyright © VirtualFluids Project contributors, see AUTHORS.md in root folder
28//
29//! \addtogroup gpu_BoundaryConditions BoundaryConditions
30//! \ingroup gpu_core core
31//! \{
32//! \author Martin Schoenherr
33//=======================================================================================
34#include <cuda_runtime.h>
35#include <helper_functions.h>
36#include <helper_cuda.h>
37
38#include "Calculation/Calculation.h"
39#include <cuda_helper/CudaGrid.h>
40
41#include "BoundaryConditions/Slip/Slip_Device.cuh"
42#include "BoundaryConditions/Slip/SlipBounceBack.cuh"
43#include "Parameter/Parameter.h"
44
45namespace vf::gpu {
46
47void SlipBounceBack(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
48{
49 vf::cuda::CudaGrid grid(parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
50 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
51
52 SlipBounceBack_Device<<< grid.grid, grid.threads >>> (
53 parameterDevice->distributions.f[0],
54 *boundaryCondition,
55 parameterDevice->neighborX,
56 parameterDevice->neighborY,
57 parameterDevice->neighborZ,
58 parameterDevice->numberOfNodes,
59 parameterDevice->isEvenTimestep);
60 getLastCudaError("SlipBounceBackDevice execution failed");
61}
62
63
64void SlipCompressible(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
65{
66 dim3 grid = vf::cuda::getCudaGrid( parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
67 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
68
69 SlipCompressible_Device<<< grid, threads >>> (
70 parameterDevice->distributions.f[0],
71 boundaryCondition->k,
72 boundaryCondition->q27[0],
73 boundaryCondition->numberOfBCnodes,
74 parameterDevice->omega,
75 parameterDevice->neighborX,
76 parameterDevice->neighborY,
77 parameterDevice->neighborZ,
78 parameterDevice->numberOfNodes,
79 parameterDevice->isEvenTimestep);
80 getLastCudaError("QSlipDeviceComp27 execution failed");
81}
82
83
84void SlipTurbulentViscosityCompressible(LBMSimulationParameter* parameterDevice, QforBoundaryConditions* boundaryCondition)
85{
86 dim3 grid = vf::cuda::getCudaGrid( parameterDevice->numberofthreads, boundaryCondition->numberOfBCnodes);
87 dim3 threads(parameterDevice->numberofthreads, 1, 1 );
88
89 SlipTurbulentViscosityCompressible_Device<<< grid, threads >>> (
90 parameterDevice->distributions.f[0],
91 boundaryCondition->k,
92 boundaryCondition->q27[0],
93 boundaryCondition->numberOfBCnodes,
94 parameterDevice->omega,
95 parameterDevice->neighborX,
96 parameterDevice->neighborY,
97 parameterDevice->neighborZ,
98 parameterDevice->turbulentViscosity,
99 parameterDevice->numberOfNodes,
100 parameterDevice->isEvenTimestep);
101 getLastCudaError("SlipTurbulentViscosityCompressible_Device execution failed");
102}
103
104}
105
106//! \}